Triples
=======
.. automodapi:: pykeen.triples
    :no-heading:
    :include-all-objects:
    :headings: --

Utilities
---------
.. automodule:: pykeen.triples.utils
    :members:


Triples Workflows
=================
Splitting
---------
.. automodapi:: pykeen.triples.splitting
    :no-heading:

Remixing
---------
.. automodapi:: pykeen.triples.remix
    :no-heading:

Deterioration
-------------
.. automodapi:: pykeen.triples.deteriorate
    :no-heading:

Generation
----------
.. automodapi:: pykeen.triples.generation
    :no-heading:

Analysis
----------
.. automodule:: pykeen.triples.analysis
    :members:
